@@ -1,9 +1,9 @@
 package aeos;
 ##
-## $Id: aeos.pm.in 3689 2017-06-29 21:50:09Z heas $
+## $Id: aeos.pm.in 3746 2017-12-12 15:53:32Z heas $
 ##
-## rancid 3.7
-## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
+## rancid 3.8
+## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -18,15 +18,9 @@ package aeos;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. All advertising materials mentioning features or use of this software
-##    must display the following acknowledgement:
-##        This product includes software developed by Henry Kilmer and John
-##        Heasley and its contributors for RANCID.
-## 4. Neither the name of RANCID nor the names of its
+## 3. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
-## 5. It is requested that non-binding fixes and modifications be contributed
-##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -67,7 +61,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.7;
+use rancid 3.8;
 
 our $found_env;
 our $found_version;
@@ -146,7 +140,7 @@ sub ShowVersion {
 
     while (<$INPUT>) {
 	tr/\015//d;
-	if (/^$prompt/) { $found_version = 1; last};
+	if (/^$prompt/) {$found_version = 1; last};
 	next if (/^(\s*|\s*$cmd\s*)$/);
 	return(1) if /^% Invalid input/;
 	return(0) if ($found_version);		# Only do this routine once
@@ -191,11 +185,11 @@ sub DiffConfig {
 sub ShowEnv {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In ShowEnv: $_" if ($debug);
-    my($fans, $supplies, $E0) = (0, 0, undef);
+    my($fans, $E0) = (0, undef);
 
     while (<$INPUT>) {
 	tr/\015//d;
-	if (/^$prompt/) { $found_env = 1; last};
+	if (/^$prompt/) {$found_env = 1; last};
 	next if (/^(\s*|\s*$cmd\s*)$/);
 	return(1) if /^% Invalid input/;
 	return(0) if ($found_env);		# Only do this routine once
@@ -206,19 +200,25 @@ sub ShowEnv {
 	}
         /^(System \S+ status is|Action on overheat|Airflow)/ &&
 	    ProcessHistory("COMMENTS","keysort","E0","!$_") && next;
-        if ( /^Fan\s+Status\s+/ ) {
+        if (/^Fan\s+Status\s+/) {
             $fans = 1;
             next;
         }
         $fans && /^\s*(\d+)\s+(\S+)/ &&
             ProcessHistory("COMMENTS","keysort","E1","!Fan $1: $2\n") && next;
-        if ( /^Supply\s+Model\s+Capacity/ ) {
-            $fans = 0;
-            $supplies = 1;
-            next;
+        if (/^supply\s+model\s+capacity/i) {
+	    while (<$INPUT>) {
+		tr/\015//d;
+		last if (/^\s*/);
+		if (/^$prompt/) {$found_version = 1; last};
+		/^\s*(\d+)\s+(\S+)\s+(\S+)\s+\S+\s+\S+\s+\S+\s+(\S+)/ &&
+		    ProcessHistory("COMMENTS","keysort","E2","!Power Supply $1: $2 $3 $4\n");
+		    next;
+		/^\s*Total\s+\S+\s+(\S+)\s+/ &&
+		    ProcessHistory("COMMENTS","keysort","E2","!Power Total: $1\n") &&
+		    next;;
+            }
         }
-        $supplies && /^\s*(\d+)\s+(\S+)\s+(\S+)\s+\S+\s+\S+\s+\S+\s+(.+)/ &&
-            ProcessHistory("COMMENTS","keysort","E2","!Power Supply $1: $2 $3 $4\n" ) && next;
     }
     ProcessHistory("COMMENTS","","","!\n");
     return(0);
@@ -255,8 +255,8 @@ sub ShowBootExt {
 	tr/\015//d;
 	last if (/^$prompt/);
 	next if (/^(\s*|\s*$cmd\s*)$/);
-	return(1) if /^% Invalid input/;
-        return(0) if /^% Error displaying /;
+	return(1) if (/^% Invalid input/);
+        return(0) if (/^% Error displaying /);
 
 	if (!defined($C0)) {
 	    $C0 = 1; ProcessHistory("COMMENTS","","","!\n");
