@@ -1,9 +1,9 @@
 package edgemax;
 ##
-## $Id: edgemax.pm.in 3376 2016-04-06 17:52:30Z heas $
+## $Id: edgemax.pm.in 3795 2018-04-10 20:48:10Z heas $
 ##
-## rancid 3.7
-## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
+## rancid 3.8
+## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -18,15 +18,9 @@ package edgemax;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. All advertising materials mentioning features or use of this software
-##    must display the following acknowledgement:
-##        This product includes software developed by Henry Kilmer and John
-##        Heasley and its contributors for RANCID.
-## 4. Neither the name of RANCID nor the names of its
+## 3. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
-## 5. It is requested that non-binding fixes and modifications be contributed
-##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -63,7 +57,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.7;
+use rancid 3.8;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -147,26 +141,6 @@ sub ShowVersion {
     return(0);
 }
 
-# This routine parses "Dir"
-sub DirSlotN {
-    my($INPUT, $OUTPUT) = @_;
-    my($slot);
-
-    print STDERR "    In DirSlotN: $_" if ($debug);
-
-    while (<$INPUT>) {
-	tr/\015//d;
-	last if (/^$prompt/);
-	next if (/^\s+\^$/);
-        return(1) if (/invalid (input|command) detected/i);
-	next if /^\s*$/;
-
-	ProcessHistory("FLASH","","","!$_");
-    }
-    ProcessHistory("FLASH","","","!\n");
-    return(0);
-}
-
 # This routine parses "show bootvar"
 sub ShowBootvar {
     my($INPUT, $OUTPUT) = @_;
