@@ -1,7 +1,9 @@
 package fss2;
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## $Id: junos.pm.in 3736 2017-11-09 18:05:12Z heas $
+##
+## rancid 3.8
+## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -54,9 +56,9 @@ use strict 'vars';
 use warnings;
 require(Exporter);
 our @ISA = qw(Exporter);
-#$Exporter::Verbose=1;
+$Exporter::Verbose=1;
 
-use rancid 3.14;
+use rancid 3.8;
 
 @ISA = qw(Exporter rancid main);
 #our @EXPORT = qw($VERSION)
@@ -182,28 +184,15 @@ sub ShowSystem {
 	last if (/^$prompt/);
 	next if /\[ok\]\[/i;
 
-	next if /system (sys-)?uptime/i;
+	next if /system uptime/i;
 	/system neType\s+(.*)/ &&
 	    ProcessHistory("COMMENTS","keysort","A1","#Chassis type: $1\n") &&
 	    next;
 	/system softwareVersion\s+(.*)/ &&
 	    ProcessHistory("COMMENTS","keysort","B1","#Image: $1\n") && next;
 
-	# drop cpu stats and process stats
-	if (/^(index\s*user type\s*|\s*cpu\s*cpu\s*$)/i) {
-	    while (<$INPUT>) {
-		tr/\015//d;
-		goto OUT if (/^$prompt/);	# should not occur
-		goto OUT if /\[ok\]\[/i;
-
-                last if (/^\s*$/);
-	    }
-	    next;
-	}
- 
 	ProcessHistory("","","","# $_");
     }
-OUT:
     return(0);
 }
 
