@@ -1,9 +1,9 @@
 package ios;
 ##
-## $Id: ios.pm.in 3717 2017-07-20 15:33:07Z heas $
+## $Id: ios.pm.in 3842 2018-07-19 01:05:03Z heas $
 ##
-## rancid 3.7
-## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
+## rancid 3.8
+## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -18,15 +18,9 @@ package ios;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. All advertising materials mentioning features or use of this software
-##    must display the following acknowledgement:
-##        This product includes software developed by Henry Kilmer and John
-##        Heasley and its contributors for RANCID.
-## 4. Neither the name of RANCID nor the names of its
+## 3. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
-## 5. It is requested that non-binding fixes and modifications be contributed
-##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -63,7 +57,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.7;
+use rancid 3.8;
 
 our $proc;
 our $ios;
@@ -994,14 +988,19 @@ sub ShowFlash {
 	    s/^$1\s{$len}//;
 	}
 
-	# filter frequently changing files (dhcp & vlan database) from flash
-	# change from:
-	# 9          660 Jan 15 2011 20:43:54 vlan.dat
-	# 9          660 Jan 15 2011 20:43:54 +00:00 vlan.dat
-	# to:
-	#                                     vlan.dat
-	#                                            vlan.dat
-	if (/(dhcp_[^. ]*\.txt|vlan\.dat|sflog|snooping|smart-log\/agentlog|syslog)\s*$/) {
+	# Drop these files entirely.
+	/\s+(private-multiple-fs|multiple-fs|LISP-MapCache-IPv\S+|nv_hdr)$/ &&
+	    next;
+
+	if (/(dhcp_[^. ]*\.txt|vlan\.dat|sflog|snooping)/ ||
+		 /(smart-log\/agentlog|syslog)\s*$/) {
+	    # filter frequently changing files (dhcp & vlan database) from flash
+	    # change from:
+	    # 9          660 Jan 15 2011 20:43:54 vlan.dat
+	    # 9          660 Jan 15 2011 20:43:54 +00:00 vlan.dat
+	    # to:
+	    #                                     vlan.dat
+	    #                                            vlan.dat
 	    if (/(\s*\d+)(\s+[-rwx]+\s+)(\d+)(\s+)(\w+ \d+\s+\d+ \d+:\d+:\d+ .\d+:\d+)/) {
 		my($fn, $a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $5, $');
 		my($fnl, $szl, $dtl) = (length($fn), length($sz), length($dt));
@@ -1026,16 +1025,16 @@ sub ShowFlash {
 		my($fmt) = "%-". $fnl ."s%s%-". $szl ."s%s%-". $dtl ."s%s";
 		$_ = sprintf($fmt, "", $a, "", $c, "", $rem);
 	    }
-	}
-
-	# filter config archives from flash
-	# change from:
-	# 9          660 Jan 15 2011 20:43:54 running-config-archive-Jul--1-16-50-27.123-113
-	# 9          660 Jan 15 2011 20:43:54 +00:00 running-config-archive-Jul--1-16-50-27.123-113
-	# to:
-	#                                     running-config-archive-<removed>
-	#                                     running-config-archive-<removed>
-	if (/(running-config-archive-)\S+\s*$/) {
+	    /\s+(\S+)\s*$/ &&
+		ProcessHistory("FLASH","keysort","$1","!Flash: $_") && next;
+	} elsif (/(running-config-archive-)\S+\s*$/) {
+	    # filter config archives from flash
+	    # change from:
+	    # 9          660 Jan 15 2011 20:43:54 running-config-archive-Jul--1-16-50-27.123-113
+	    # 9          660 Jan 15 2011 20:43:54 +00:00 running-config-archive-Jul--1-16-50-27.123-113
+	    # to:
+	    #                                     running-config-archive-<removed>
+	    #                                     running-config-archive-<removed>
 	    my($arc) = $1;
 	    if (/(\s*\d+)(\s+[-rwx]+\s+)(\d+)(\s+)(\w+ \d+\s+\d+ \d+:\d+:\d+ .\d+:\d+)/) {
 		my($fn, $a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $5, $');
@@ -1058,13 +1057,16 @@ sub ShowFlash {
 		my($fmt) = "%-". $fnl ."s%s%-". $szl ."s%s%-". $dtl ."s%s%s\n";
 		$_ = sprintf($fmt, "", $a, "", $c, "", $arc, "<removed>");
 	    }
-	}
+	    /\s+(\S+)\s*$/ &&
+		ProcessHistory("FLASH","keysort","$1","!Flash: $_") && next;
+	} elsif (/^(\s*\d+)(\s+[-rwx]+\s+\d+\s+\w+ \d+\s+\d+ \d+:\d+:\d+ .\d+:\d+\s+)(\S+)/ ||
+		 /^(\s*\d+)(\s+[-rwx]+\s+\d+\s+\w+ \d+\s+\d+ \d+:\d+:\d+\s+)(\S+)/ ||
+		 /^(\s*\d+)(\s+\d+\s+\w+ \d+\s+\d+ \d+:\d+:\d+ .\d+:\d+\s+)(\S+)/ ||
+		 /^(\s*\d+)(\s+\d+\s+\w+ \d+\s+\d+ \d+:\d+:\d+\s+)(\S+)/) {
+	    ProcessHistory("FLASH","keysort","$2","!Flash: $1$2$3\n") && next;
+        }
 
-	# Drop these files entirely.
-	/\s+(private-multiple-fs|multiple-fs|LISP-MapCache-IPv\S+|nv_hdr)$/ &&
-	    next;
-
-	if (/(\d+) bytes (available|total) \((\d+) bytes (free|used)\)/) {
+	if (/(\d+) bytes (available|total) \((\d+) bytes (free|used)(\/\s+% free)?\)/) {
 	    my($avail);
 	    my($preamble) = "";
 	    if ($2 eq "available") {
@@ -1127,61 +1129,18 @@ sub DirSlotN {
 	return(-1) if (/\%Error opening \S+:\S+ \(Device or resource busy\)/i);
 	return(-1) if (/command authorization failed/i);
 	return(1) if (/(Open device \S+ failed|Error opening \S+:)/);
+	# the pager can not be disabled per-session on the PIX
+	if (/^(<-+ More -+>)/) {
+	    my($len) = length($1);
+	    s/^$1\s{$len}//;
+	}
+
 	# skip dir sup-bootflash if dir sup-bootdisk was successful, duplicates
 	if ($cmd =~ / sup-bootdisk/) {
 	    $supbootdisk++;
 	} elsif ($supbootdisk && $cmd =~ / sup-bootflash/) {
 	    return(0);
 	}
-	# filter frequently changing files from IOX bootflash
-	if ($dev =~ /bootflash/) {
-	    next if (/temp_cont\s*$/);
-	    next if (/uptime_cont\s*$/);
-	    next if (/volt_cont\s*$/);
-	}
-
-	# filter frequently changing files (dhcp & vlan database)
-	# change from:
-	#    9  -rw-         660  Jan 15 2011 20:43:54 vlan.dat
-	#    9  -rw-         660  Jan 15 2011 20:43:54 +00:00  vlan.dat
-	# to:
-	#       -rw-                                   vlan.dat
-	#       -rw-                                           vlan.dat
-	if (/(dhcp_[^. ]*\.txt|vlan\.dat|sflog|snooping|syslog)\s*$/) {
-	    if (/(\s*\d+)(\s+\S+\s+)(\d+)(\s+)(\w+ \d+\s+\d+ \d+:\d+:\d+ .\d+:\d+)/) {
-		my($fn, $a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $5, $');
-		my($fnl, $szl, $dtl) = (length($fn), length($sz), length($dt));
-		my($fmt) = "%-". $fnl ."s%s%-". $szl ."s%s%-". $dtl ."s%s";
-		$_ = sprintf($fmt, "", $a, "", $c, "", $rem);
-	    } elsif (/(\s*\d+)(\s+\S+\s+)(\d+)(\s+)(\w+ \d+\s+\d+ \d+:\d+:\d+)/) {
-		my($fn, $a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $5, $');
-		my($fnl, $szl, $dtl) = (length($fn), length($sz), length($dt));
-		my($fmt) = "%-". $fnl ."s%s%-". $szl ."s%s%-". $dtl ."s%s";
-		$_ = sprintf($fmt, "", $a, "", $c, "", $rem);
-	    }
-	}
-
-	# filter frequently changing files (dhcp & vlan database)
-	# change from:
-	#    9  -rw-         660  Jan 15 2011 20:43:54 running-config-archive-Jul--1-16-50-27.123-113
-	#    9  -rw-         660  Jan 15 2011 20:43:54 +00:00  running-config-archive-Jul--1-16-50-27.123-113
-	# to:
-	#       -rw-                                   running-config-archive-Jul--1-16-50-27.123-113
-	#       -rw-                                           running-config-archive-Jul--1-16-50-27.123-113
-	if (/(running-config-archive-)\S+\s*$/) {
-	    my($arc) = $1;
-	    if (/(\s*\d+)(\s+\S+\s+)(\d+)(\s+)(\w+ \d+\s+\d+ \d+:\d+:\d+ .\d+:\d+)/) {
-		my($fn, $a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $5, $');
-		my($fnl, $szl, $dtl) = (length($fn), length($sz), length($dt));
-		my($fmt) = "%-". $fnl ."s%s%-". $szl ."s%s%-". $dtl ."s%s%s\n";
-		$_ = sprintf($fmt, "", $a, "", $c, "", $arc, "<removed>");
-	    } elsif (/(\s*\d+)(\s+\S+\s+)(\d+)(\s+)(\w+ \d+\s+\d+ \d+:\d+:\d+)/) {
-		my($fn, $a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $5, $');
-		my($fnl, $szl, $dtl) = (length($fn), length($sz), length($dt));
-		my($fmt) = "%-". $fnl ."s%s%-". $szl ."s%s%-". $dtl ."s%s%s\n";
-		$_ = sprintf($fmt, "", $a, "", $c, "", $arc, "<removed>");
-	    }
-	}
 
 	# Drop LISP cache.
 	/\s+LISP-MapCache-IPv\S+$/ && next;
@@ -1190,30 +1149,93 @@ sub DirSlotN {
 	# on dual RP ASR systems
 	next if (/\.issu_loc_lock\s*$/);
 
-	if (/.*\((\d+) bytes free\)/) {
-	    my($tmp) = $1;
-	    if ($tmp >= (1024 * 1024 * 1024)) {
-		$tmp = int($tmp / (1024 * 1024 * 1024));
-		s/$1 bytes free/$tmp GB free/;
-	    } elsif ($tmp >= (1024 * 1024)) {
-		$tmp = int($tmp / (1024 * 1024));
-		s/$1 bytes free/$tmp MB free/;
-	    } elsif ($tmp >= (1024)) {
-		$tmp = int($tmp / 1024);
-		s/$1 bytes free/$tmp KB free/;
-	    } elsif ($tmp > 0) {
-		s/$1 bytes free/< 1KB free/;
-	    } else {
-		s/$1 bytes free/0 bytes free/;
+	# vASA nonsense
+	# 9 file(s) total size: 252854822 bytes
+	next if (/\d+ file\S+ total size: \d+ bytes/i);
+
+	# filter frequently changing files (dhcp & vlan database)
+	# change from:
+	#    9  -rw-         660  Jan 15 2011 20:43:54 vlan.dat
+	#    9  -rw-         660  Jan 15 2011 20:43:54 +00:00  vlan.dat
+	# to:
+	#       -rw-                                   vlan.dat
+	#       -rw-                                           vlan.dat
+	if (/(dhcp_[^. ]*\.txt|vlan\.dat|sflog|snooping|syslog)\s*$/ ||
+	    /(tracelogs|throughput_monitor_params|underlying-config)\s*$/) {
+	    if (/(\s*\d+\s+)(\S+\s+)(\d+)(\s+)(\w+ \d+\s+\d+ \d+:\d+:\d+ .\d+:\d+)/) {
+		my($fn, $a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $5, $');
+		my($fnl, $szl, $dtl) = (length($fn), length($sz), length($dt));
+		my($fmt) = "%s%-". $szl ."s%s%-". $dtl ."s%s";
+		$_ = sprintf($fmt, $a, "", $c, "", $rem);
+	    } elsif (/(\s*\d+\s+)(\S+\s+)(\d+)(\s+)(\w+ \d+\s+\d+ \d+:\d+:\d+)/) {
+		my($fn, $a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $5, $');
+		my($fnl, $szl, $dtl) = (length($fn), length($sz), length($dt));
+		my($fmt) = "%s%-". $szl ."s%s%-". $dtl ."s%s";
+		$_ = sprintf($fmt, $a, "", $c, "", $rem);
+	    } elsif (/(\s*\d+\s+)(\S+\s+)(\d+)(\s+<no date>)/i) {
+		# 32771  -rw-            24520                    <no date>  underlying-config
+		my($fn, $a, $sz, $dt, $rem) = ($1, $2, $3, $4, $');
+		my($fnl, $szl) = (length($fn), length($sz));
+		my($fmt) = "%s%-". $szl ."s%s%s";
+		$_ = sprintf($fmt, $a, "", $dt, $rem);
+	    }
+	    /\s+(\S+)\s*$/ &&
+		ProcessHistory("FLASH","keysort","$1","!Flash: $dev: $_") &&
+		next;
+	} elsif (/(running-config-archive-)\S+\s*$/) {
+	    my($arc) = $1;
+
+	    # filter frequently changing files of the config archive feature
+	    # change from:
+	    #    9  -rw-         660  Jan 15 2011 20:43:54 running-config-archive-Jul--1-16-50-27.123-113
+	    #    9  -rw-         660  Jan 15 2011 20:43:54 +00:00  running-config-archive-Jul--1-16-50-27.123-113
+	    # to:
+	    #       -rw-                                   running-config-archive-Jul--1-16-50-27.123-113
+	    #       -rw-                                           running-config-archive-Jul--1-16-50-27.123-113
+	    if (/(\s*\d+\s+)(\S+\s+)(\d+)(\s+)(\w+ \d+\s+\d+ \d+:\d+:\d+ .\d+:\d+)/) {
+		my($fn, $a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $5, $');
+		my($fnl, $szl, $dtl) = (length($fn), length($sz), length($dt));
+		my($fmt) = "%s%-". $szl ."s%s%-". $dtl ."s%s%s\n";
+		$_ = sprintf($fmt, $a, "", $c, "", $arc, "<removed>");
+	    } elsif (/(\s*\d+\s+)(\S+\s+)(\d+)(\s+)(\w+ \d+\s+\d+ \d+:\d+:\d+)/) {
+		my($fn, $a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $5, $');
+		my($fnl, $szl, $dtl) = (length($fn), length($sz), length($dt));
+		my($fmt) = "%s%-". $szl ."s%s%-". $dtl ."s%s%s\n";
+		$_ = sprintf($fmt, $a, "", $c, "", $arc, "<removed>");
+	    }
+	    /\s+(\S+)\s*$/ &&
+		ProcessHistory("FLASH","keysort","$1","!Flash: $dev: $_") &&
+		next;
+	} else {
+	    # drop file number (from the various formats):
+	    #     3  -rw-             1011                    <no date>  ifIndex-table
+	    #    9  -rw-         660  Jan 15 2011 20:43:54 vlan.dat
+	    #   16  -rw-             5437  Jan 16 2016 02:22:32 +00:00  licenses
+	    if (/(\s*\d+\s+)(\S+\s+\d+\s+\w+ \d+\s+\d+ \d+:\d+:\d+ .\d+:\d+)/ ||
+	        /(\s*\d+\s+)(\S+\s+\d+\s+\w+ \d+\s+\d+ \d+:\d+:\d+)/ ||
+	        /(\s*\d+\s+)(\S+\s+\d+\s+<no date>\s+\S+)/) {
+		#my($fn, $a, $rem) = ($1, $2, $');
+		#my($fnl) = length($fn);
+		#my($fmt) = "%-". $fnl ."s%s%s\n";
+		#$_ = sprintf($fmt, "", $a, $rem);
+		$_ = $2 . $';
+		/\s+(\S+)\s*$/ &&
+		    ProcessHistory("FLASH","keysort","$1","!Flash: $dev: $_") &&
+		    next;
 	    }
 	}
-	if ($ios eq "XE" && /^((\s+)?\d+\s+\S+)\s+\d+.*(tracelogs|throughput_monitor_params)$/) {
-	    $_ = "$1" . sprintf("%43s", "") . "$3\n";
+
+	# XE: 822083584 bytes total (821081600 bytes free)
+	if (/^\s*(\d+) bytes total\s+\((\d+) bytes free\)/i) {
+	    ProcessHistory("FLASH","","","!Flash: $dev: " .
+			   diskszsummary($1, $2) . "\n");
+	    next;
 	}
-	# the pager can not be disabled per-session on the PIX
-	if (/^(<-+ More -+>)/) {
-	    my($len) = length($1);
-	    s/^$1\s{$len}//;
+	# vASA: 8571076608 bytes total (8306561024 bytes free/96% free)
+	if (/^\s*(\d+) bytes total \((\d+) bytes free\/\d+% free\)/) {
+	    ProcessHistory("FLASH","","","!Flash: $dev: " .
+			   diskszsummary($1, $2) . "\n");
+	    next;
 	}
 
 	ProcessHistory("FLASH","","","!Flash: $dev: $_");
@@ -1646,7 +1668,7 @@ REDUX:	tr/\015//d;
 	}
 	# 7200, 3800, 3600, 2600, and 1700 stuff
 	if (/^(Slot)\s+(\d+(\/\d+)?):/
-	    || /^\s+(PVDM|WIC|VIC|WIC\/VIC) Slot (\d):/
+	    || /^\s+(PVDM|WIC|VIC|WIC\/VIC|WIC\/VIC\/HWIC) Slot (\d):/
 	    || /^(Encryption AIM) (\d):/
 	    || /^(AIM Module in slot:) (\d)/) {
 	    if ($1 eq "PVDM") {
@@ -1657,6 +1679,8 @@ REDUX:	tr/\015//d;
 		$WIC = "/$2";
 	    } elsif ($1 eq "WIC/VIC") {
 		$WIC = "/$2";
+	    } elsif ($1 eq "WIC/VIC/HWIC") {
+		$WIC = "/$2";
 	    } elsif ($1 eq "DSP") {
 		$WIC = "/$2";
 	    } elsif ($1 eq "Encryption AIM") {
@@ -2361,7 +2385,6 @@ TOP:
 	    my($expath) = $_;
 	    while (<$INPUT>) {
 		tr/\015//d;
-		last if (/^$prompt/);
 		last if (/^$prompt/ || ! /^(ip explicit-path name |[ !])/);
 		if (/^ip explicit-path name (\S+)/) {
 		    ProcessHistory("EXPATH","keysort","$key","$expath");
