@@ -1,9 +1,9 @@
 package iosxr;
 ##
-## $Id: iosxr.pm.in 3726 2017-08-17 15:38:28Z heas $
+## $Id: iosxr.pm.in 3841 2018-07-18 16:22:59Z heas $
 ##
-## rancid 3.7
-## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
+## rancid 3.8
+## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -18,15 +18,9 @@ package iosxr;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. All advertising materials mentioning features or use of this software
-##    must display the following acknowledgement:
-##        This product includes software developed by Henry Kilmer and John
-##        Heasley and its contributors for RANCID.
-## 4. Neither the name of RANCID nor the names of its
+## 3. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
-## 5. It is requested that non-binding fixes and modifications be contributed
-##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -63,7 +57,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.7;
+use rancid 3.8;
 
 our $proc;
 our $found_env;
@@ -579,6 +573,7 @@ sub DirSlotN {
 	return(1) if (/^(-+\^|syntax error: unknown argument)$/i);	# NCS
 	return(1) if (/(No such device|Error Sending Request)/i);
 	return(1) if (/: path doesnot exists/i);	# NCS
+	return(1) if (/: Path does not exist/i);	# NCS
 	return(1) if (/\%Error: No such file or directory/);
 	return(1) if (/\%Error: No route to host/);
 	return(1) if (/No space information available/);
@@ -590,10 +585,21 @@ sub DirSlotN {
 	return(-1) if (/\%Error opening \S+:\S+ \(Device or resource busy\)/i);
 	return(-1) if (/command authorization failed/i);
 	return(1) if (/(Open device \S+ failed|Error opening \S+:)/);
+
+	# Filter dhcp database
+	if (/dhcp_[^. ]*\.txt/) {
+	    next;
+	}
+	# Filter debugging file dlbg.txt & dlbg.txt-1 only on ASR9k w/ XR
+	if ($proc =~ /ASR9K/ && /dlbg\.txt/) {
+	    next;
+	}
 	# filter frequently changing files from IOX bootflash, hardiska,
 	# and nvram
 	if ($dev =~ /(bootflash|disk0|harddisk|nvram)/) {
-	    if (/\s(aaa|ce_switch.log|errmsg_cont|genstr_cont|temp_cont|temp_static_data|uptime_cont|volt_cont)\s*$/) {
+	    if (/\s(\.python-history|aaa|\.bash_history|ce_switch.log)\s*$/ ||
+	        /\s(cisco_support|errmsg_cont|genstr_cont|temp_cont)\s*$/ ||
+	        /\s(temp_cont|temp_static_data|uptime_cont|volt_cont)\s*$/) {
 		# change
 		# 57          -rw-  23100       <no date>              volt_cont
 		# 614788      drwx  4096        Fri Aug 20 12:06:25 2010  temp_cont
@@ -605,6 +611,14 @@ sub DirSlotN {
 		    my($szl) = length($sz);
 		    my($fmt) = "%s%-". $szl ."s%s%s%s";
 		    $_ = sprintf($fmt, $a, "", $c, $dt, $rem);
+		} elsif (/(\s*\d+)(\s+\S+\s+\d+\s+)(\d+\s+\w+\s+\d+\s+\d+:\d+)/) {
+		    # XR >= 6.3; dir disk0:, but harddisk: is diff format.  wtf
+		    # drop fileno size, & date.
+		    # " 8002 drwxr-xr-x 2 4096 Jan 17 15:27 np"
+		    my($fn, $perm, $dt, $rem) = ($1, $2, $3, $');
+		    my($fnl, $dtl) = (length($fn), length($dt));
+		    my($fmt) = "%-". $fnl ."s%s%-". $dtl ."s%s";
+		    $_ = sprintf($fmt, "", $perm, "", $rem);
 		} elsif (/(\s*\d+\s+\S+\s+)(\d+)(\s+)(\w+ \w+\s+\d+ \d+:\d+:\d+ \d+)/) {
 		    my($a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $');
 		    my($szl, $dtl) = (length($sz), length($dt));
@@ -613,30 +627,14 @@ sub DirSlotN {
 		}
 	    }
 	}
-	# Filter dhcp database
-	if (/dhcp_[^. ]*\.txt/) {
+
+	# XR: 822083584 bytes total (821081600 bytes free)
+	# eXR: 990484 kbytes total (813208 kbytes free)
+	if (/^\s*(\d+ k?bytes) total\s+\((\d+ k?bytes) free\)/i) {
+	    ProcessHistory("FLASH","","","!Flash: $dev: " .
+			   diskszsummary($1, $2) . "\n");
 	    next;
 	}
-	# Filter debugging file dlbg.txt & dlbg.txt-1 only on ASR9k w/ XR
-	if ($proc =~ /ASR9K/ && /dlbg\.txt/) {
-	    next;
-	}
-	if (/.*\((\d+) (k?bytes) free\)/) {
- 	    my($tmp) = $1;
- 	    my($sz) = $2;
-	    $tmp *= 1024 if ($sz eq "kbytes");	# NCS summarizes in kbytes
-	
-	    if ($tmp >= (1024 * 1024 * 1024)) {
-		$tmp = int($tmp / (1024 * 1024 * 1024));
-		s/$1 $sz free/$tmp GB free/;
-	    } elsif ($tmp >= (1024 * 1024)) {
-		$tmp = int($tmp / (1024 * 1024));
-		s/$1 $sz free/$tmp MB free/;
-	    } else {
-		$tmp = int($tmp / 1024);
-		s/$1 $sz free/$tmp KB free/;
-	    }
-	}
 
 	ProcessHistory("FLASH","","","!Flash: $dev: $_");
     }
