@@ -1,9 +1,9 @@
 package junos;
 ##
-## $Id: junos.pm.in 3699 2017-07-18 13:40:55Z heas $
+## $Id: junos.pm.in 3788 2018-04-06 23:42:45Z heas $
 ##
-## rancid 3.7
-## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
+## rancid 3.8
+## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -18,15 +18,9 @@ package junos;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. All advertising materials mentioning features or use of this software
-##    must display the following acknowledgement:
-##        This product includes software developed by Henry Kilmer and John
-##        Heasley and its contributors for RANCID.
-## 4. Neither the name of RANCID nor the names of its
+## 3. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
-## 5. It is requested that non-binding fixes and modifications be contributed
-##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -64,7 +58,7 @@ require(Exporter);
 our @ISA = qw(Exporter);
 $Exporter::Verbose=1;
 
-use rancid 3.7;
+use rancid 3.8;
 
 our $ShowChassisSCB;			# Only run ShowChassisSCB() once
 
@@ -459,7 +453,7 @@ sub ShowSystemLicense {
 	#                                  Licenses     Licenses    Licenses    Expiry
 	#   Feature name                       used    installed      needed
 	#   dynamic-vpn                           1            2           0    permanent
-	if (/^(\s+(?:VMX|dynamic|mobile|scale|service|subscriber)-\S+)(\s+)(\d+)(\s+\d+)(.*$)/) {
+	if (/^(\s+(?:VMX|dynamic|mobile|scale|service|scale-subscriber|subscriber)-\S+)(\s+)(\d+)(\s+\d+)(.*$)/) {
 	    my($a, $sp, $used, $avail, $rem) = ($1, $2, $3, $4, $5);
 	    my($spl, $usedl) = (length($sp), length($used));
 	    my($pcnt, $usage, $usagel);
@@ -560,7 +554,7 @@ sub ShowVersion {
 	next if (/^system (shutdown message from|going down )/i);
 	next if (/^\{(master|backup)(:\d+)?\}/);
 	/error: abnormal communication termination with / && return(-1);
-	/error: Could not connect to \S+ : No route to host / && return(-1);
+	/error: could not connect to \S+ : no route to host/i && return(-1);
 
 	/warning: .* subsystem not running - not needed by configuration/ && next;
 
