@@ -1,9 +1,9 @@
 package nxos;
 ##
-## $Id: nxos.pm.in 3677 2017-06-21 18:39:24Z heas $
+## $Id: nxos.pm.in 3843 2018-07-19 01:21:29Z heas $
 ##
-## rancid 3.7
-## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
+## rancid 3.8
+## Copyright (c) 1997-2018 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -18,15 +18,9 @@ package nxos;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. All advertising materials mentioning features or use of this software
-##    must display the following acknowledgement:
-##        This product includes software developed by Henry Kilmer and John
-##        Heasley and its contributors for RANCID.
-## 4. Neither the name of RANCID nor the names of its
+## 3. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
-## 5. It is requested that non-binding fixes and modifications be contributed
-##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -63,7 +57,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.7;
+use rancid 3.8;
 
 our $proc;
 our $ios;
@@ -313,6 +307,7 @@ sub ShowRedundancy {
 	return(1) if /Line has invalid autocommand /;
 	return(1) if /(Invalid input detected|Type help or )/;
 	return(1) if (/\% Invalid command at /);
+	return(1) if (/.* command is not support/i);
 	return(-1) if (/No token match at /);	# 1000v
 	return(-1) if (/\% Permission denied/);
 	return(-1) if (/command authorization failed/i);
@@ -337,6 +332,7 @@ sub ShowEnv {
 	return(1) if /Line has invalid autocommand /;
 	return(1) if /(Invalid input detected|Type help or )/;
 	return(1) if (/\% Invalid command at /);
+	return(1) if (/ .* command is not support/i);
 	return(1) if (/No token match at /);	# 1000v
 	return(-1) if (/\% Permission denied/);
 	return(-1) if (/command authorization failed/i);
@@ -346,6 +342,8 @@ sub ShowEnv {
 	if (/(control temperature|monitor temperature)/i) {
 	    ProcessHistory("COMMENTS","","","!Env: $_");
 	    while (<$INPUT>) {
+		tr/\015//d;
+		goto EndShowEnv if (/^$prompt/);
 		if (/(.*\s+\d+\s+\d+\s+)(\d+)(.*$)/) {
 		    $_ = sprintf("%s%-". length($2)."s%s\n", $1, "", $3);
 		}
@@ -356,6 +354,7 @@ sub ShowEnv {
 	}
 	ProcessHistory("COMMENTS","","","!Env: $_");
     }
+EndShowEnv:
     ProcessHistory("COMMENTS","","","!\n");
     return(0);
 }
@@ -510,6 +509,7 @@ sub ShowBoot {
 sub DirSlotN {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In DirSlotN: $_" if ($debug);
+    my($free);
 
     my($dev) = (/\s([^\s]+):/);
 
@@ -544,7 +544,8 @@ sub DirSlotN {
 	/\s+vtp_debug(_old)?\.log$/ && next;
 
 	next if (/BufferMonitor-1HourData/);
-	if (/ log\/$/) {
+
+	if (/( debug_logs| log)\/$/) {
 	    # change
 	    #         8192    Jan 08 14:05:05 2015  log/
 	    # to
@@ -557,9 +558,13 @@ sub DirSlotN {
 	    }
 	}
 
-	if (/^\s*(\d+) bytes /) {
-	    my($tmp) = int($1 / (1024 * 1024));
-	    s/$1 bytes /$tmp MB /;
+	if (/^\s*(\d+) bytes free/i) {
+	    $free = $1;
+	    next;
+	} elsif (/^\s*(\d+) bytes used/i) {
+	    next;
+	} elsif (/^\s*(\d+) bytes total/i) {
+	    $_ = diskszsummary($1, $free, undef) . "\n";
 	}
 
 	ProcessHistory("COMMENTS","","","!Flash: $dev: $_");
@@ -594,6 +599,30 @@ sub ShowModule {
     return(0);
 }
 
+# This routine parses "show interface transceiver".
+sub ShowIntTransceiver {
+    my($INPUT, $OUTPUT, $cmd) = @_;
+    print STDERR "    In ShowtTransceiver: $_" if ($debug);
+
+    while (<$INPUT>) {
+	tr/\015//d;
+	return if (/^\s*\^$/);
+	last if (/^$prompt/);
+	next if (/^(\s*|\s*$cmd\s*)$/);
+	return(1) if /Line has invalid autocommand /;
+	return(1) if /(Invalid input detected|Type help or )/;
+	return(1) if (/\% Invalid command at /);
+	return(-1) if (/No token match at /);	# 1000v
+	return(-1) if (/\% Permission denied/);
+	return(-1) if (/command authorization failed/i);
+
+	ProcessHistory("COMMENTS","","","!$_");
+    }
+    ProcessHistory("COMMENTS","","","!\n");
+
+    return(0);
+}
+
 # This routine parses "show inventory".
 sub ShowInventory {
     my($INPUT, $OUTPUT, $cmd) = @_;
